Colors - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

- Home
- Interface
  Empty page Accordion Blank page Buttons
  Cards New
  Sample cards Card actions New Cards Masonry
  Colors Dropdowns Modals Maps Map fullsize Vector maps New Navigation
  Charts Pagination Placeholder Tabs Tables Carousel Lists Typography Offcanvas Markdown
  Authentication
  Sign in Sign up Forgot password Terms of service Lock screen
  Error pages
  404 page 500 page Maintenance page
- Form elements
- Extra
  Activity Gallery Invoice Search results Pricing cards Users License Music Tasks New Uptime monitor Widgets Wizard
- Layout
  Horizontal Boxed Vertical Vertical transparent Right vertical Condensed Combined
  Navbar dark Navbar sticky Navbar overlap RTL mode Fluid Fluid vertical
- 1518 icons
- Documentation
- Changelog

## Colors

bl | az | in | pu | pi | re | or | ye | li | gr | te | cy | da | mu
bl | az | in | pu | pi | re | or | ye | li | gr | te | cy | da | mu
bl | az | in | pu | pi | re | or | ye | li | gr | te | cy | da | mu
bl | az | in | pu | pi | re | or | ye | li | gr | te | cy | da | mu
bl | az | in | pu | pi | re | or | ye | li | gr | te | cy | wh | mu
bl | az | in | pu | pi | re | or | ye | li | gr | te | cy | wh | mu